==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/ApiPortalCustomDomainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin

import com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs.builder
import com.pulumi.azurenative.appplatform.kotlin.inputs.ApiPortalCustomDomainPropertiesArgs
import com.pulumi.azurenative.appplatform.kotlin.inputs.ApiPortalCustomDomainPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Custom domain of the API portal
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2022-01-01-preview.
 * Other available API versions: 2023-07-01-preview, 2023-09-01-preview, 2023-11-01-preview.
 * ## Example Usage
 * ### ApiPortalCustomDomains_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var apiPortalCustomDomain = new AzureNative.AppPlatform.ApiPortalCustomDomain("apiPortalCustomDomain", new()
 *     {
 *         ApiPortalName = "default",
 *         DomainName = "myDomainName",
 *         Properties = new AzureNative.AppPlatform.Inputs.ApiPortalCustomDomainPropertiesArgs
 *         {
 *             Thumbprint = "*",
 *         },
 *         ResourceGroupName = "myResourceGroup",
 *         ServiceName = "myservice",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/appplatform/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := appplatform.NewApiPortalCustomDomain(ctx, "apiPortalCustomDomain", &appplatform.ApiPortalCustomDomainArgs{
 * 			ApiPortalName: pulumi.String("default"),
 * 			DomainName:    pulumi.String("myDomainName"),
 * 			Properties: &appplatform.ApiPortalCustomDomainPropertiesArgs{
 * 				Thumbprint: pulumi.String("*"),
 * 			},
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 			ServiceName:       pulumi.String("myservice"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomain;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var apiPortalCustomDomain = new ApiPortalCustomDomain("apiPortalCustomDomain", ApiPortalCustomDomainArgs.builder()
 *             .apiPortalName("default")
 *             .domainName("myDomainName")
 *             .properties(Map.of("thumbprint", "*"))
 *             .resourceGroupName("myResourceGroup")
 *             .serviceName("myservice")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appplatform:ApiPortalCustomDomain myDomainName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/apiPortals/{apiPortalName}/domains/{domainName}
 * ```
 * @property apiPortalName The name of API portal.
 * @property domainName The name of the API portal custom domain.
 * @property properties The properties of custom domain for API portal
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class ApiPortalCustomDomainArgs(
    public val apiPortalName: Output<String>? = null,
    public val domainName: Output<String>? = null,
    public val properties: Output<ApiPortalCustomDomainPropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serviceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs =
        com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs.builder()
            .apiPortalName(apiPortalName?.applyValue({ args0 -> args0 }))
            .domainName(domainName?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApiPortalCustomDomainArgs].
 */
@PulumiTagMarker
public class ApiPortalCustomDomainArgsBuilder internal constructor() {
    private var apiPortalName: Output<String>? = null

    private var domainName: Output<String>? = null

    private var properties: Output<ApiPortalCustomDomainPropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var serviceName: Output<String>? = null

    /**
     * @param value The name of API portal.
     */
    @JvmName("ttfiopxntfprxudd")
    public suspend fun apiPortalName(`value`: Output<String>) {
        this.apiPortalName = value
    }

    /**
     * @param value The name of the API portal custom domain.
     */
    @JvmName("rfeyiulvfudhjydf")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value The properties of custom domain for API portal
     */
    @JvmName("xiordrwhkjexgsgk")
    public suspend fun properties(`value`: Output<ApiPortalCustomDomainPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("nycprcbxqkeshyxe")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("xrjdbnlcbtgmbhwj")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value The name of API portal.
     */
    @JvmName("dgfinmcpggllwvde")
    public suspend fun apiPortalName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiPortalName = mapped
    }

    /**
     * @param value The name of the API portal custom domain.
     */
    @JvmName("potcsxoocrqisiay")
    public suspend fun domainName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value The properties of custom domain for API portal
     */
    @JvmName("lyqejkqrvbhfgvgk")
    public suspend fun properties(`value`: ApiPortalCustomDomainPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument The properties of custom domain for API portal
     */
    @JvmName("gurnmjobkoiqlvgt")
    public suspend
    fun properties(argument: suspend ApiPortalCustomDomainPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ApiPortalCustomDomainPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("gmgrvwaagdotgopw")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("pdpjpadyyjxxwenx")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    internal fun build(): ApiPortalCustomDomainArgs = ApiPortalCustomDomainArgs(
        apiPortalName = apiPortalName,
        domainName = domainName,
        properties = properties,
        resourceGroupName = resourceGroupName,
        serviceName = serviceName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/ApiPortalCustomDomainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin

import com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs.builder
import com.pulumi.azurenative.appplatform.kotlin.inputs.ApiPortalCustomDomainPropertiesArgs
import com.pulumi.azurenative.appplatform.kotlin.inputs.ApiPortalCustomDomainPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Custom domain of the API portal
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2022-01-01-preview.
 * Other available API versions: 2023-07-01-preview, 2023-09-01-preview, 2023-11-01-preview, 2023-12-01, 2024-01-01-preview.
 * ## Example Usage
 * ### ApiPortalCustomDomains_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var apiPortalCustomDomain = new AzureNative.AppPlatform.ApiPortalCustomDomain("apiPortalCustomDomain", new()
 *     {
 *         ApiPortalName = "default",
 *         DomainName = "myDomainName",
 *         Properties = new AzureNative.AppPlatform.Inputs.ApiPortalCustomDomainPropertiesArgs
 *         {
 *             Thumbprint = "*",
 *         },
 *         ResourceGroupName = "myResourceGroup",
 *         ServiceName = "myservice",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/appplatform/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := appplatform.NewApiPortalCustomDomain(ctx, "apiPortalCustomDomain", &appplatform.ApiPortalCustomDomainArgs{
 * 			ApiPortalName: pulumi.String("default"),
 * 			DomainName:    pulumi.String("myDomainName"),
 * 			Properties: &appplatform.ApiPortalCustomDomainPropertiesArgs{
 * 				Thumbprint: pulumi.String("*"),
 * 			},
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 			ServiceName:       pulumi.String("myservice"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomain;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var apiPortalCustomDomain = new ApiPortalCustomDomain("apiPortalCustomDomain", ApiPortalCustomDomainArgs.builder()
 *             .apiPortalName("default")
 *             .domainName("myDomainName")
 *             .properties(Map.of("thumbprint", "*"))
 *             .resourceGroupName("myResourceGroup")
 *             .serviceName("myservice")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appplatform:ApiPortalCustomDomain myDomainName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/apiPortals/{apiPortalName}/domains/{domainName}
 * ```
 * @property apiPortalName The name of API portal.
 * @property domainName The name of the API portal custom domain.
 * @property properties The properties of custom domain for API portal
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class ApiPortalCustomDomainArgs(
    public val apiPortalName: Output<String>? = null,
    public val domainName: Output<String>? = null,
    public val properties: Output<ApiPortalCustomDomainPropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serviceName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs =
        com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs.builder()
            .apiPortalName(apiPortalName?.applyValue({ args0 -> args0 }))
            .domainName(domainName?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApiPortalCustomDomainArgs].
 */
@PulumiTagMarker
public class ApiPortalCustomDomainArgsBuilder internal constructor() {
    private var apiPortalName: Output<String>? = null

    private var domainName: Output<String>? = null

    private var properties: Output<ApiPortalCustomDomainPropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var serviceName: Output<String>? = null

    /**
     * @param value The name of API portal.
     */
    @JvmName("wpvqqimjhfetcwga")
    public suspend fun apiPortalName(`value`: Output<String>) {
        this.apiPortalName = value
    }

    /**
     * @param value The name of the API portal custom domain.
     */
    @JvmName("dgsqxwkbbfxerkrs")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value The properties of custom domain for API portal
     */
    @JvmName("akwmmtecocngpyei")
    public suspend fun properties(`value`: Output<ApiPortalCustomDomainPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("widndjxyhrdjnlcr")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("tohpvanqdvgnvfpc")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value The name of API portal.
     */
    @JvmName("cylfmtjgjdftsomm")
    public suspend fun apiPortalName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiPortalName = mapped
    }

    /**
     * @param value The name of the API portal custom domain.
     */
    @JvmName("pbvgfldfdyxqqwtw")
    public suspend fun domainName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value The properties of custom domain for API portal
     */
    @JvmName("eapcpirasbwrnjkk")
    public suspend fun properties(`value`: ApiPortalCustomDomainPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument The properties of custom domain for API portal
     */
    @JvmName("sijexiwkolyixqcf")
    public suspend
    fun properties(argument: suspend ApiPortalCustomDomainPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ApiPortalCustomDomainPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("vushraavauosshrt")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("ugdxfeukwqukmmiv")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    internal fun build(): ApiPortalCustomDomainArgs = ApiPortalCustomDomainArgs(
        apiPortalName = apiPortalName,
        domainName = domainName,
        properties = properties,
        resourceGroupName = resourceGroupName,
        serviceName = serviceName,
    )
}
